@@ -1,4 +1,4 @@
-#! /usr/bin/env python
+#!/usr/global/paper/bin/python
 """
 A script for fitting parameters of a measurement equation given 
 starting parameters in a cal file and a list of sources.  The fitter used
@@ -24,6 +24,14 @@ o.add_option('--xtol', dest='xtol', type='float', default=1e-10,
     help='Fractional change sought in it parameters before convergence.  Default 1e-10.')
 o.add_option('--ftol', dest='ftol', type='float', default=1e-10,
     help='Fractional tolerance sought in score before convergence.  Default 1e-10.')
+o.add_option('--remem', dest='remember', action='store_true',
+    help='Remember values from last fit when fitting in snapshot mode.')
+o.add_option('--baseport', dest='baseport', type='int', default=53000,
+    help="Base port # to use for tx/rx.  Each daemon adds it's daemon id to this to determine the actual port used for TCP transactions.")
+o.add_option('--daemon', dest='daemon', type='int', 
+    help='Operate in daemon mode, opening a TCP Server to handle requests on the specified increment to the base port.')
+o.add_option('--master', dest='master', 
+    help='Operate in master mode, employing daemon-mode servers to do the work and collecting the results.  Should be a comma delimited list of host:daemonid pairs to contact.  Daemon ID will be added to baseport to determine actual port used for TCP transactions.')
 o.add_option('--sim_autos', dest='sim_autos', action='store_true',
     help='Use auto-correlations in fitting.  Default is to use only cross-correlations.')
 
@@ -36,8 +44,8 @@ a.scripting.uv_selector(uv, opts.ant, opts.pol)
 aa = a.cal.get_aa(opts.cal, uv['sdf'], uv['sfreq'], uv['nchan'])
 chans = a.scripting.parse_chans(opts.chan, uv['nchan'])
 aa.select_chans(chans)
-srclist,cutoff = a.scripting.parse_srcs(opts.src)
-cat = a.cal.get_catalog(opts.cal, srclist, cutoff)
+srclist,cutoff,catalogs = a.scripting.parse_srcs(opts.src, opts.cat)
+cat = a.cal.get_catalog(opts.cal, srclist, cutoff, catalogs)
 (uvw,t,(i,j)),d = uv.read()
 aa.set_jultime(t)
 cat.compute(aa)
@@ -96,6 +104,7 @@ def fit_func(prms, filelist, decimate, decphs):
     score,nsamples = 0.,0.
     # Cache data from file to avoid hitting disk excessively
     if dbuf is None:
+        if not opts.quiet: print 'Caching data...'
         dbuf = {}
         for uvfile in filelist:
             sys.stdout.write('.') ; sys.stdout.flush()
@@ -106,9 +115,23 @@ def fit_func(prms, filelist, decimate, decphs):
                 if not dbuf.has_key(t): dbuf[t] = {}
                 if not opts.sim_autos and i == j: continue
                 bl = a.miriad.ij2bl(i,j)
-                dbuf[t][bl] = (d.take(chans), f.take(chans), 
+                d = d.take(chans)
+                f = f.take(chans)
+                dbuf[t][bl] = (d, f, 
                         n.where(f, 0, n.abs(d)**2).sum(),
                         a.miriad.pol2str[uv['pol']])
+        if not opts.quiet:
+            samp, vsamp, wgts = 0, 0, 0.
+            for t in dbuf:
+              for bl in dbuf[t]:
+                samp += len(dbuf[t][bl][1])
+                vsamp += n.logical_not(dbuf[t][bl][1]).astype(n.int).sum()
+                wgts += dbuf[t][bl][2]
+            print 'Cache summary:'
+            print '   %d samples' % samp
+            print '   %d valid' % vsamp
+            print '   %f sum weights' %  wgts
+            sys.stdout.flush()
     # Process data from cache
     for t in dbuf:
         aa.set_jultime(t)
@@ -126,6 +149,7 @@ def fit_func(prms, filelist, decimate, decphs):
             difsq = n.where(f, 0, difsq)
             score += difsq.sum()
             nsamples += nsamp
+    if opts.daemon: return score, nsamples
     if nsamples == 0:
         first_fit = 0.
         return 0.
@@ -135,11 +159,83 @@ def fit_func(prms, filelist, decimate, decphs):
         print
         print 'Score:', score, 
         print '(%2.2f%% of %f)' % (100 * score / first_fit, first_fit)
-        print '------------------------------------------------------------'
+        print '-' * 70
     return score / first_fit
 
 # Call the optimizer
-if not opts.snap:
+if opts.daemon:
+    import SocketServer, struct
+    class TCPServer(SocketServer.TCPServer):
+        allow_reuse_address = True
+    class FitHandler(SocketServer.BaseRequestHandler):
+        def setup(self): print self.client_address, 'connected'
+        def finish(self): print self.client_address, 'disconnected'
+        def handle(self):
+            data = self.request.recv(struct.calcsize('d')*len(prm_list))
+            data = struct.unpack('<%dd' % (len(prm_list)), data)
+            score, nsamples = fit_func(data, args, opts.decimate, opts.decphs)
+            print 'Returning score=%f, nsamples=%f' % (score, nsamples)
+            rv = struct.pack('<dd', score, nsamples)
+            self.request.send(rv)
+            sys.stdout.flush()
+    s = TCPServer(('', opts.baseport + opts.daemon), FitHandler)
+    print 'Starting daemon on TCP port %d' % (opts.baseport + opts.daemon)
+    sys.stdout.flush()
+    s.serve_forever()
+elif opts.master:
+    import socket, struct
+    def parsehostport(hostport):
+        host, port = hostport.split(':')
+        return (host, opts.baseport + int(port))
+    hostports = [parsehostport(w) for w in opts.master.split(',')]
+    def fit_func(prms):
+        global first_fit
+        if first_fit == 0: return 0
+        pdict = a.fit.reconstruct_prms(prms, key_list)
+        if not opts.quiet: a.fit.print_params(pdict)
+        data = struct.pack('<%dd' % (len(prms)), *prms)
+        socks = []
+        for hostport in hostports:
+            sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+            sock.connect(hostport)
+            sock.send(data)
+            socks.append(sock)
+        score, nsamples = 0, 0
+        for sock in socks:
+            data = sock.recv(1024)
+            scr, nsp = struct.unpack('<dd', data)
+            score += scr; nsamples += nsp
+            if not opts.quiet: print score, nsamples
+        score = n.sqrt(score / nsamples)
+        if nsamples == 0:
+            first_fit = 0.
+            return 0.
+        if first_fit is None: first_fit = score
+        if not opts.quiet:
+            print
+            print 'Score:', score, 
+            print '(%2.2f%% of %f)' % (100 * score / first_fit, first_fit)
+            print '-' * 70
+        return score / first_fit
+    print 'Starting in master mode...'
+    rv = a.optimize.fmin(
+        fit_func, prm_list,
+        #args=(args, opts.decimate, opts.decphs),
+        full_output=1, disp=0,
+        maxfun=opts.maxiter, maxiter=n.Inf, 
+        ftol=opts.ftol, xtol=opts.xtol
+    )
+    prms,score = rv[:2]
+    prms = a.fit.reconstruct_prms(prms, key_list)
+    print
+    a.fit.print_params(prms)
+    print 'Score:', score * first_fit, 
+    print '(%2.2f%% of %f)' % (100 * score, first_fit)
+    print '------------------------------------------------------------'
+            
+    
+
+elif not opts.snap:
     rv = a.optimize.fmin(
         fit_func, prm_list,
         args=(args, opts.decimate, opts.decphs),
@@ -185,3 +281,4 @@ else:
             print 'Score:', score * first_fit, 
             print '(%2.2f%% of %f)' % (100 * score, first_fit)
             print '------------------------------------------------------------'
+            if opts.remember: prm_list, key_list = a.fit.flatten_prms(prms)
