@@ -1,4 +1,4 @@
-#! /usr/bin/env python
+#!/usr/global/paper/bin/python
 """
 Script for displaying a projection of a spherical (Healpix) data set stored
 in a *.fits file.
@@ -63,7 +63,8 @@ except(ImportError):
 o = optparse.OptionParser()
 o.set_usage('plot_map.py [options] mapfile')
 o.set_description(__doc__)
-a.scripting.add_standard_options(o, src=True, cmap=True, max=True, drng=True)
+a.scripting.add_standard_options(o, cal=True, src=True, 
+    cmap=True, max=True, drng=True)
 o.add_option('-p', '--projection', dest='projection', default='moll',
     help='Map projection to use: moll (default), mill, cyl, robin, sinu.')
 o.add_option('-m', '--mode', dest='mode', default='log',
@@ -142,8 +143,11 @@ data.shape = lats.shape
 
 # Generate source locations
 if not opts.src is None:
-    srclist,cutoff = a.scripting.parse_srcs(opts.src)
-    cat = a.src.get_catalog(srcs=srclist, cutoff=cutoff)
+    srclist,cutoff,catalogs = a.scripting.parse_srcs(opts.src, opts.cat)
+    if not opts.cal is None:
+        cat = a.cal.get_catalog(opts.cal, srclist, cutoff, catalogs)
+    else:
+        cat = a.src.get_catalog(srclist, cutoff, catalogs)
     o = ephem.Observer()
     if opts.juldate is None:
         o.date = ephem.J2000
@@ -202,6 +206,11 @@ if not opts.src is None:
 if not opts.nobar: p.colorbar(shrink=.5, format='%.2f')
 else: p.subplots_adjust(.05,.05,.95,.95)
 
+
+def mk_arr(val, dtype=n.double):
+    if type(val) is n.ndarray: return val.astype(dtype)
+    return n.array(val, dtype=dtype).flatten()
+
 if opts.outfile != '':
     print 'Saving to', opts.outfile
     p.savefig(opts.outfile)
@@ -210,17 +219,31 @@ else:
     cnt = 1
     def click(event):
         global cnt
-        if event.button != 3: return
-        lon,lat = map(event.xdata, event.ydata, inverse=True)
-        if opts.osys == 'eq': lon = (360 - lon) % 360
-        lon *= a.img.deg2rad; lat *= a.img.deg2rad
-        ra,dec = ephem.hours(lon), ephem.degrees(lat)
-        x,y,z = a.coord.radec2eq((ra,dec))
-        flx = h[(x,y,z)]
-        print '#%d (RA,DEC): (%s, %s), Jy: %f' % (cnt, ra, dec, flx)
-        cnt += 1
+        if event.button == 3: 
+            lon,lat = map(event.xdata, event.ydata, inverse=True)
+            if opts.osys == 'eq': lon = (360 - lon) % 360
+            lon *= a.img.deg2rad; lat *= a.img.deg2rad
+            ra,dec = ephem.hours(lon), ephem.degrees(lat)
+            x,y,z = a.coord.radec2eq((ra,dec))
+            flx = h[(x,y,z)]
+            print '#%d (RA,DEC): (%s, %s), Jy: %f' % (cnt, ra, dec, flx)
+            cnt += 1
+        elif event.button==2:
+            lon,lat = map(event.xdata, event.ydata, inverse=True)
+            if opts.osys == 'eq': lon = (360 - lon) % 360
+            lon *= a.img.deg2rad; lat *= a.img.deg2rad
+            ra,dec = ephem.hours(lon), ephem.degrees(lat)
+            x,y,z = a.coord.radec2eq((ra,dec))
+            #flx = h[(x,y,z)]
+            crd = [mk_arr(c, dtype=n.double) for c in (x,y,z)]
+            px,wgts = h.crd2px(*crd, **{'interpolate':1})
+            flx = n.sum(h[px],axis=-1)
+            print '#%d (RA,DEC): (%s, %s), Jy: %f (4px sum)' % (cnt, ra, dec, flx)
+            cnt += 1
+        else: return
+            
+
 
     #register this function with the event handler
     p.connect('button_press_event', click)
-
     p.show()
