@@ -77,19 +77,21 @@ def parse_ants(ant_str, nants):
                     rv.append((bl,include))
     return rv
 
-def uv_selector(uv, ants, pol_str):
+def uv_selector(uv, ants=-1, pol_str=-1):
     """Call uv.select with appropriate options based on string argument for
     antennas (can be 'all', 'auto', 'cross', '0,1,2', or '0_1,0_2') and
     string for polarization ('xx','yy','xy','yx')."""
-    if type(ants) == str: ants = parse_ants(ants, uv['nants'])
-    for bl,include in ants:
-        if bl == 'auto': uv.select('auto', 0, 0, include=include)
-        else:
-            i,j = miriad.bl2ij(bl)
-            uv.select('antennae', i, j, include=include)
-    try: polopt = miriad.str2pol[pol_str]
-    except(KeyError): raise ValueError('--pol argument invalid or absent')
-    uv.select('polarization', polopt, 0)
+    if ants != -1:
+        if type(ants) == str: ants = parse_ants(ants, uv['nants'])
+        for bl,include in ants:
+            if bl == 'auto': uv.select('auto', 0, 0, include=include)
+            else:
+                i,j = miriad.bl2ij(bl)
+                uv.select('antennae', i, j, include=include)
+    if pol_str != -1:
+        try: polopt = miriad.str2pol[pol_str]
+        except(KeyError): raise ValueError('--pol argument invalid or absent')
+        uv.select('polarization', polopt, 0)
 
 def parse_chans(chan_str, nchan, concat=True):
     """Return array of active channels based on number of channels and
@@ -117,14 +119,17 @@ def parse_srcs(src_str, cat_str):
         cutoff = map(float, src_str.split('/'))
         return None, cutoff, cats
     src_opt = src_str.split(',')
-    if len(src_opt) == 1:
-        src_opt = src_opt[0].split('_')
-        if len(src_opt) == 1: return src_opt, None, cats
-        ra,dec = src_opt
-        s = fit.RadioFixedBody(ra, dec, name=src_str)
-        return [s], None, cats
-    else:
-        return src_opt, None, cats
+    for i, s in enumerate(src_opt):
+        radec = s.split('_')
+        try:
+            assert(len(radec) == 2)
+            ra,dec = radec
+            # Check that this is really an ra_dec pair
+            for piece in ra.split(':'): piece = float(piece)
+            for piece in dec.split(':'): piece = float(piece)
+            src_opt[i] = fit.RadioFixedBody(ra,dec, name=s)
+        except(AssertionError,ValueError): continue
+    return src_opt, None, cats
 
 name = r'([^\(/,\)=]+)'
 grp = r'(%s|\((%s(/%s)*)\))' % tuple([name]*3)
